==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/CONTRACTANDRENTALDETAILS.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VEHICLETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISRENTAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RENTALTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISCONTRACT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AVAILABILITYSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUETO" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "vehicletype",
    "isrental",
    "rentaltemplateid",
    "iscontract",
    "contracttemplateid",
    "customerid",
    "availabilitystatus",
    "issueto"
})
@XmlRootElement(name = "CONTRACTANDRENTALDETAILS")
public class CONTRACTANDRENTALDETAILS {

    @XmlElement(name = "VEHICLETYPE")
    protected TYPE_Type vehicletype;
    @XmlElement(name = "ISRENTAL", defaultValue = "false")
    protected String isrental;
    @XmlElement(name = "RENTALTEMPLATEID")
    protected RENTALTEMPLATEID_Type rentaltemplateid;
    @XmlElement(name = "ISCONTRACT", defaultValue = "false")
    protected String iscontract;
    @XmlElement(name = "CONTRACTTEMPLATEID")
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "CUSTOMERID")
    protected CUSTOMERID_Type customerid;
    @XmlElement(name = "AVAILABILITYSTATUS")
    protected STATUS_Type availabilitystatus;
    @XmlElement(name = "ISSUETO")
    protected PERSONID_Type issueto;

    /**
     * Obtient la valeur de la propriété vehicletype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getVEHICLETYPE() {
        return vehicletype;
    }

    /**
     * Définit la valeur de la propriété vehicletype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setVEHICLETYPE(TYPE_Type value) {
        this.vehicletype = value;
    }

    /**
     * Obtient la valeur de la propriété isrental.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISRENTAL() {
        return isrental;
    }

    /**
     * Définit la valeur de la propriété isrental.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISRENTAL(String value) {
        this.isrental = value;
    }

    /**
     * Obtient la valeur de la propriété rentaltemplateid.
     * 
     * @return
     *     possible object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public RENTALTEMPLATEID_Type getRENTALTEMPLATEID() {
        return rentaltemplateid;
    }

    /**
     * Définit la valeur de la propriété rentaltemplateid.
     * 
     * @param value
     *     allowed object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public void setRENTALTEMPLATEID(RENTALTEMPLATEID_Type value) {
        this.rentaltemplateid = value;
    }

    /**
     * Obtient la valeur de la propriété iscontract.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISCONTRACT() {
        return iscontract;
    }

    /**
     * Définit la valeur de la propriété iscontract.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISCONTRACT(String value) {
        this.iscontract = value;
    }

    /**
     * Obtient la valeur de la propriété contracttemplateid.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Définit la valeur de la propriété contracttemplateid.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Obtient la valeur de la propriété customerid.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public CUSTOMERID_Type getCUSTOMERID() {
        return customerid;
    }

    /**
     * Définit la valeur de la propriété customerid.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public void setCUSTOMERID(CUSTOMERID_Type value) {
        this.customerid = value;
    }

    /**
     * Obtient la valeur de la propriété availabilitystatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getAVAILABILITYSTATUS() {
        return availabilitystatus;
    }

    /**
     * Définit la valeur de la propriété availabilitystatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setAVAILABILITYSTATUS(STATUS_Type value) {
        this.availabilitystatus = value;
    }

    /**
     * Obtient la valeur de la propriété issueto.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getISSUETO() {
        return issueto;
    }

    /**
     * Définit la valeur de la propriété issueto.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setISSUETO(PERSONID_Type value) {
        this.issueto = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/CONTRACTANDRENTALDETAILS.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}VEHICLETYPE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISRENTAL" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RENTALTEMPLATEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISCONTRACT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}AVAILABILITYSTATUS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISSUETO" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "vehicletype",
    "isrental",
    "rentaltemplateid",
    "iscontract",
    "contracttemplateid",
    "customerid",
    "availabilitystatus",
    "issueto"
})
@XmlRootElement(name = "CONTRACTANDRENTALDETAILS")
public class CONTRACTANDRENTALDETAILS {

    @XmlElement(name = "VEHICLETYPE")
    protected TYPE_Type vehicletype;
    @XmlElement(name = "ISRENTAL", defaultValue = "false")
    protected String isrental;
    @XmlElement(name = "RENTALTEMPLATEID")
    protected RENTALTEMPLATEID_Type rentaltemplateid;
    @XmlElement(name = "ISCONTRACT", defaultValue = "false")
    protected String iscontract;
    @XmlElement(name = "CONTRACTTEMPLATEID")
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "CUSTOMERID")
    protected CUSTOMERID_Type customerid;
    @XmlElement(name = "AVAILABILITYSTATUS")
    protected STATUS_Type availabilitystatus;
    @XmlElement(name = "ISSUETO")
    protected PERSONID_Type issueto;

    /**
     * Gets the value of the vehicletype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getVEHICLETYPE() {
        return vehicletype;
    }

    /**
     * Sets the value of the vehicletype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setVEHICLETYPE(TYPE_Type value) {
        this.vehicletype = value;
    }

    /**
     * Gets the value of the isrental property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISRENTAL() {
        return isrental;
    }

    /**
     * Sets the value of the isrental property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISRENTAL(String value) {
        this.isrental = value;
    }

    /**
     * Gets the value of the rentaltemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public RENTALTEMPLATEID_Type getRENTALTEMPLATEID() {
        return rentaltemplateid;
    }

    /**
     * Sets the value of the rentaltemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public void setRENTALTEMPLATEID(RENTALTEMPLATEID_Type value) {
        this.rentaltemplateid = value;
    }

    /**
     * Gets the value of the iscontract property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISCONTRACT() {
        return iscontract;
    }

    /**
     * Sets the value of the iscontract property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISCONTRACT(String value) {
        this.iscontract = value;
    }

    /**
     * Gets the value of the contracttemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Sets the value of the contracttemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Gets the value of the customerid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public CUSTOMERID_Type getCUSTOMERID() {
        return customerid;
    }

    /**
     * Sets the value of the customerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public void setCUSTOMERID(CUSTOMERID_Type value) {
        this.customerid = value;
    }

    /**
     * Gets the value of the availabilitystatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getAVAILABILITYSTATUS() {
        return availabilitystatus;
    }

    /**
     * Sets the value of the availabilitystatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setAVAILABILITYSTATUS(STATUS_Type value) {
        this.availabilitystatus = value;
    }

    /**
     * Gets the value of the issueto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getISSUETO() {
        return issueto;
    }

    /**
     * Sets the value of the issueto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setISSUETO(PERSONID_Type value) {
        this.issueto = value;
    }

}
